@@ -20,31 +20,17 @@ class Network3Medusa():
     def network3_medusa(self):
         self.py2output()
         raw_json=self.output.stdout.decode('utf-8')
-        if self.command == "show running-config":
-            first = True
-            for line in raw_json.split('\n'):
-                if first:
-                    first = False
-                    print(line)
-                    self.add_file_to_hedera(f"{ line } \n")
-                else:
-                    print(line)
-                    self.append_file_to_hedera(f"{ line } \n")
-            query = FileInfoQuery().setFileId(self.fileId)
-            info = query.execute(self.client)
-            print("File size according to `FileInfoQuery`: ", info.size)
-        else:
-            size = 6000
-            chunks = [raw_json[i:i+size] for i in range (0, len(raw_json), size)]
-            first = True
-            for chunk in chunks:
-                if first == True:
-                    first = False
-                    self.add_file_to_hedera(chunk)            
-                else:
-                    self.append_file_to_hedera(chunk)           
-            if WEBEX_ROOM:
-                self.send_webex_notification()          
+        size = 5500
+        chunks = [raw_json[i:i+size] for i in range (0, len(raw_json), size)]
+        first = True
+        for chunk in chunks:
+            if first == True:
+                first = False
+                self.add_file_to_hedera(chunk)            
+            else:
+                self.append_file_to_hedera(chunk)           
+        if WEBEX_ROOM:
+            self.send_webex_notification()          
     def py2output(self):
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
 
@@ -53,7 +39,6 @@ class Network3Medusa():
         self.client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
         tran = FileCreateTransaction()
         fileContents = chunk
-        print(fileContents)
         resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(self.client)
         print("nodeId: ",  resp.nodeId.toString())
         self.nodeId = resp.nodeId.toString()
